.. automodule:: merlin
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   merlin.algorithms
   merlin.builder
   merlin.core
   merlin.datasets
   merlin.measurement
   merlin.pcvl_pytorch
   merlin.utils

Submodules
----------

.. toctree::
   :maxdepth: 1

   merlin.algorithms.kernels
   merlin.utils
